Welcome to *autoBOT*'s documentation
===================================

`autoBOT <https://github.com/SkBlaz/autobot/>`_ is an autoML system for automatic explainable classification of *texts*. It includes automatically generated features at different granularities, evolved to offer optimal performance/explainability tradeoff.

.. toctree::
   :maxdepth: 3
   :caption: About:

   key_idea.rst
	   
.. toctree::
   :maxdepth: 3
   :caption: Tutorial and first steps:

   installation.rst
   core_idea.rst
   suggested_use.rst
   features.rst
   custom_classifiers.rst
   custom_features.rst
   model_persistence.rst
   representations.rst
   cli_usage.rst
   containerization.rst
   custom_knowledge.rst
   custom_metrics.rst
   ideas.rst
   updates.rst
   api.rst
   cluster.rst
   shared_tasks.rst

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   modules.rst
   
..
   Method index
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
